@@ -18,10 +18,13 @@ app = Flask(__name__)
 assets = Environment(app)
 
 if settings.SERVER:
-    static_path = '/var/cache/linkmanager/static'
-    assets.directory = static_path
+    var_path = '/var/cache/linkmanager'
+    if not os.path.exists(var_path):
+        os.makedirs(var_path, mode=0o755)
+    static_path = os.path.join(var_path, 'static')
     if not os.path.exists(static_path):
-        os.makedirs(static_path, mode=0o755)
+        os.symlink(assets.directory, static_path)
+    assets.directory = static_path
 
 db = DataBase()
 
